/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Ratings schemes. The country-specific ratings are mostly for movies and shows.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ContentRating extends GenericJson {

  /**
   * Rating system in Australia - Australian Classification Board
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String acbRating;

  /**
   * British Board of Film Classification
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bbfcRating;

  /**
   * Rating system in India - Central Board of Film Certification
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String cbfcRating;

  /**
   * Canadian Home Video Rating System
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String chvrsRating;

  /**
   * Rating system in Brazil - Department of Justice, Rating, Titles and Qualification
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String djctqRating;

  /**
   * Rating system in Japan - Eiga Rinri Kanri Iinkai
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String eirinRating;

  /**
   * Rating system in France - French Minister of Culture
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String fmocRating;

  /**
   * Rating system in Germany - Voluntary Self Regulation of the Movie Industry
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String fskRating;

  /**
   * Rating system in Spain - Instituto de Cinematografia y de las Artes Audiovisuales
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String icaaRating;

  /**
   * Rating system in South Korea - Korea Media Rating Board
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kmrbRating;

  /**
   * Motion Picture Association of America rating for the content.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String mpaaRating;

  /**
   * Rating system in New Zealand - Office of Film and Literature Classification
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String oflcRating;

  /**
   * Rating system in Mexico - General Directorate of Radio, Television and Cinematography
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String rtcRating;

  /**
   * Rating system in Russia
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String russiaRating;

  /**
   * TV Parental Guidelines rating of the content.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String tvpgRating;

  /**
   * Internal YouTube rating.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String ytRating;

  /**
   * Rating system in Australia - Australian Classification Board
   * The value returned may be {@code null}.
   */
  public String getAcbRating() {
    return acbRating;
  }

  /**
   * Rating system in Australia - Australian Classification Board
   * The value set may be {@code null}.
   */
  public ContentRating setAcbRating(String acbRating) {
    this.acbRating = acbRating;
    return this;
  }

  /**
   * British Board of Film Classification
   * The value returned may be {@code null}.
   */
  public String getBbfcRating() {
    return bbfcRating;
  }

  /**
   * British Board of Film Classification
   * The value set may be {@code null}.
   */
  public ContentRating setBbfcRating(String bbfcRating) {
    this.bbfcRating = bbfcRating;
    return this;
  }

  /**
   * Rating system in India - Central Board of Film Certification
   * The value returned may be {@code null}.
   */
  public String getCbfcRating() {
    return cbfcRating;
  }

  /**
   * Rating system in India - Central Board of Film Certification
   * The value set may be {@code null}.
   */
  public ContentRating setCbfcRating(String cbfcRating) {
    this.cbfcRating = cbfcRating;
    return this;
  }

  /**
   * Canadian Home Video Rating System
   * The value returned may be {@code null}.
   */
  public String getChvrsRating() {
    return chvrsRating;
  }

  /**
   * Canadian Home Video Rating System
   * The value set may be {@code null}.
   */
  public ContentRating setChvrsRating(String chvrsRating) {
    this.chvrsRating = chvrsRating;
    return this;
  }

  /**
   * Rating system in Brazil - Department of Justice, Rating, Titles and Qualification
   * The value returned may be {@code null}.
   */
  public String getDjctqRating() {
    return djctqRating;
  }

  /**
   * Rating system in Brazil - Department of Justice, Rating, Titles and Qualification
   * The value set may be {@code null}.
   */
  public ContentRating setDjctqRating(String djctqRating) {
    this.djctqRating = djctqRating;
    return this;
  }

  /**
   * Rating system in Japan - Eiga Rinri Kanri Iinkai
   * The value returned may be {@code null}.
   */
  public String getEirinRating() {
    return eirinRating;
  }

  /**
   * Rating system in Japan - Eiga Rinri Kanri Iinkai
   * The value set may be {@code null}.
   */
  public ContentRating setEirinRating(String eirinRating) {
    this.eirinRating = eirinRating;
    return this;
  }

  /**
   * Rating system in France - French Minister of Culture
   * The value returned may be {@code null}.
   */
  public String getFmocRating() {
    return fmocRating;
  }

  /**
   * Rating system in France - French Minister of Culture
   * The value set may be {@code null}.
   */
  public ContentRating setFmocRating(String fmocRating) {
    this.fmocRating = fmocRating;
    return this;
  }

  /**
   * Rating system in Germany - Voluntary Self Regulation of the Movie Industry
   * The value returned may be {@code null}.
   */
  public String getFskRating() {
    return fskRating;
  }

  /**
   * Rating system in Germany - Voluntary Self Regulation of the Movie Industry
   * The value set may be {@code null}.
   */
  public ContentRating setFskRating(String fskRating) {
    this.fskRating = fskRating;
    return this;
  }

  /**
   * Rating system in Spain - Instituto de Cinematografia y de las Artes Audiovisuales
   * The value returned may be {@code null}.
   */
  public String getIcaaRating() {
    return icaaRating;
  }

  /**
   * Rating system in Spain - Instituto de Cinematografia y de las Artes Audiovisuales
   * The value set may be {@code null}.
   */
  public ContentRating setIcaaRating(String icaaRating) {
    this.icaaRating = icaaRating;
    return this;
  }

  /**
   * Rating system in South Korea - Korea Media Rating Board
   * The value returned may be {@code null}.
   */
  public String getKmrbRating() {
    return kmrbRating;
  }

  /**
   * Rating system in South Korea - Korea Media Rating Board
   * The value set may be {@code null}.
   */
  public ContentRating setKmrbRating(String kmrbRating) {
    this.kmrbRating = kmrbRating;
    return this;
  }

  /**
   * Motion Picture Association of America rating for the content.
   * The value returned may be {@code null}.
   */
  public String getMpaaRating() {
    return mpaaRating;
  }

  /**
   * Motion Picture Association of America rating for the content.
   * The value set may be {@code null}.
   */
  public ContentRating setMpaaRating(String mpaaRating) {
    this.mpaaRating = mpaaRating;
    return this;
  }

  /**
   * Rating system in New Zealand - Office of Film and Literature Classification
   * The value returned may be {@code null}.
   */
  public String getOflcRating() {
    return oflcRating;
  }

  /**
   * Rating system in New Zealand - Office of Film and Literature Classification
   * The value set may be {@code null}.
   */
  public ContentRating setOflcRating(String oflcRating) {
    this.oflcRating = oflcRating;
    return this;
  }

  /**
   * Rating system in Mexico - General Directorate of Radio, Television and Cinematography
   * The value returned may be {@code null}.
   */
  public String getRtcRating() {
    return rtcRating;
  }

  /**
   * Rating system in Mexico - General Directorate of Radio, Television and Cinematography
   * The value set may be {@code null}.
   */
  public ContentRating setRtcRating(String rtcRating) {
    this.rtcRating = rtcRating;
    return this;
  }

  /**
   * Rating system in Russia
   * The value returned may be {@code null}.
   */
  public String getRussiaRating() {
    return russiaRating;
  }

  /**
   * Rating system in Russia
   * The value set may be {@code null}.
   */
  public ContentRating setRussiaRating(String russiaRating) {
    this.russiaRating = russiaRating;
    return this;
  }

  /**
   * TV Parental Guidelines rating of the content.
   * The value returned may be {@code null}.
   */
  public String getTvpgRating() {
    return tvpgRating;
  }

  /**
   * TV Parental Guidelines rating of the content.
   * The value set may be {@code null}.
   */
  public ContentRating setTvpgRating(String tvpgRating) {
    this.tvpgRating = tvpgRating;
    return this;
  }

  /**
   * Internal YouTube rating.
   * The value returned may be {@code null}.
   */
  public String getYtRating() {
    return ytRating;
  }

  /**
   * Internal YouTube rating.
   * The value set may be {@code null}.
   */
  public ContentRating setYtRating(String ytRating) {
    this.ytRating = ytRating;
    return this;
  }

}
