/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Describes information necessary for ingesting an RTMP or an HTTP stream.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class IngestionInfo extends GenericJson {

  /**
   * The backup ingestion URL that you should use to stream video to YouTube. You have the option of
   * simultaneously streaming the content that you are sending to the ingestionAddress to this URL.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String backupIngestionAddress;

  /**
   * The primary ingestion URL that you should use to stream video to YouTube. You must stream video
   * to this URL.
   *
   * Depending on which application or tool you use to encode your video stream, you may need to
   * enter the stream URL and stream name separately or you may need to concatenate them in the
   * following format:
   *
   * STREAM_URL/STREAM_NAME
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String ingestionAddress;

  /**
   * The HTTP or RTMP stream name that YouTube assigns to the video stream.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String streamName;

  /**
   * The backup ingestion URL that you should use to stream video to YouTube. You have the option of
   * simultaneously streaming the content that you are sending to the ingestionAddress to this URL.
   * The value returned may be {@code null}.
   */
  public String getBackupIngestionAddress() {
    return backupIngestionAddress;
  }

  /**
   * The backup ingestion URL that you should use to stream video to YouTube. You have the option of
   * simultaneously streaming the content that you are sending to the ingestionAddress to this URL.
   * The value set may be {@code null}.
   */
  public IngestionInfo setBackupIngestionAddress(String backupIngestionAddress) {
    this.backupIngestionAddress = backupIngestionAddress;
    return this;
  }

  /**
   * The primary ingestion URL that you should use to stream video to YouTube. You must stream video
   * to this URL.
   *
   * Depending on which application or tool you use to encode your video stream, you may need to
   * enter the stream URL and stream name separately or you may need to concatenate them in the
   * following format:
   *
   * STREAM_URL/STREAM_NAME
   * The value returned may be {@code null}.
   */
  public String getIngestionAddress() {
    return ingestionAddress;
  }

  /**
   * The primary ingestion URL that you should use to stream video to YouTube. You must stream video
   * to this URL.
   *
   * Depending on which application or tool you use to encode your video stream, you may need to
   * enter the stream URL and stream name separately or you may need to concatenate them in the
   * following format:
   *
   * STREAM_URL/STREAM_NAME
   * The value set may be {@code null}.
   */
  public IngestionInfo setIngestionAddress(String ingestionAddress) {
    this.ingestionAddress = ingestionAddress;
    return this;
  }

  /**
   * The HTTP or RTMP stream name that YouTube assigns to the video stream.
   * The value returned may be {@code null}.
   */
  public String getStreamName() {
    return streamName;
  }

  /**
   * The HTTP or RTMP stream name that YouTube assigns to the video stream.
   * The value set may be {@code null}.
   */
  public IngestionInfo setStreamName(String streamName) {
    this.streamName = streamName;
    return this;
  }

}
