/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * A liveBroadcast resource represents an event that will be streamed, via live video, on YouTube.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class LiveBroadcast extends GenericJson {

  /**
   * The contentDetails object contains information about the event's video content, such as whether
   * the content can be shown in an embedded video player or if it will be archived and therefore
   * available for viewing after the event has concluded.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LiveBroadcastContentDetails contentDetails;

  /**
   * Etag of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The ID that YouTube assigns to uniquely identify the broadcast.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind, fixed to "youtube#liveBroadcast".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The snippet object contains basic details about the event, including its title, description,
   * start time, and end time.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LiveBroadcastSnippet snippet;

  /**
   * The status object contains information about the event's status.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LiveBroadcastStatus status;

  /**
   * The contentDetails object contains information about the event's video content, such as whether
   * the content can be shown in an embedded video player or if it will be archived and therefore
   * available for viewing after the event has concluded.
   * The value returned may be {@code null}.
   */
  public LiveBroadcastContentDetails getContentDetails() {
    return contentDetails;
  }

  /**
   * The contentDetails object contains information about the event's video content, such as whether
   * the content can be shown in an embedded video player or if it will be archived and therefore
   * available for viewing after the event has concluded.
   * The value set may be {@code null}.
   */
  public LiveBroadcast setContentDetails(LiveBroadcastContentDetails contentDetails) {
    this.contentDetails = contentDetails;
    return this;
  }

  /**
   * Etag of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * Etag of this resource.
   * The value set may be {@code null}.
   */
  public LiveBroadcast setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The ID that YouTube assigns to uniquely identify the broadcast.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID that YouTube assigns to uniquely identify the broadcast.
   * The value set may be {@code null}.
   */
  public LiveBroadcast setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind, fixed to "youtube#liveBroadcast".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "youtube#liveBroadcast".
   * The value set may be {@code null}.
   */
  public LiveBroadcast setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The snippet object contains basic details about the event, including its title, description,
   * start time, and end time.
   * The value returned may be {@code null}.
   */
  public LiveBroadcastSnippet getSnippet() {
    return snippet;
  }

  /**
   * The snippet object contains basic details about the event, including its title, description,
   * start time, and end time.
   * The value set may be {@code null}.
   */
  public LiveBroadcast setSnippet(LiveBroadcastSnippet snippet) {
    this.snippet = snippet;
    return this;
  }

  /**
   * The status object contains information about the event's status.
   * The value returned may be {@code null}.
   */
  public LiveBroadcastStatus getStatus() {
    return status;
  }

  /**
   * The status object contains information about the event's status.
   * The value set may be {@code null}.
   */
  public LiveBroadcast setStatus(LiveBroadcastStatus status) {
    this.status = status;
    return this;
  }

}
