/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for LiveBroadcastSnippet.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class LiveBroadcastSnippet extends GenericJson {

  /**
   * The date and time that the broadcast actually ended. This information is only available once
   * the broadcast's state is complete. The value is specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ)
   * format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime actualEndTime;

  /**
   * The date and time that the broadcast actually started. This information is only available once
   * the broadcast's state is live. The value is specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ)
   * format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime actualStartTime;

  /**
   * The ID that YouTube uses to uniquely identify the channel that is publishing the broadcast.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelId;

  /**
   * The broadcast's description. As with the title, you can set this field by modifying the
   * broadcast resource or by setting the description field of the corresponding video resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The date and time that the broadcast was added to YouTube's live broadcast schedule. The value
   * is specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime publishedAt;

  /**
   * The date and time that the broadcast is scheduled to end. The value is specified in ISO 8601
   * (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime scheduledEndTime;

  /**
   * The date and time that the broadcast is scheduled to start. The value is specified in ISO 8601
   * (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime scheduledStartTime;

  /**
   * A map of thumbnail images associated with the broadcast. For each nested object in this object,
   * the key is the name of the thumbnail image, and the value is an object that contains other
   * information about the thumbnail.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ThumbnailDetails thumbnails;

  /**
   * The broadcast's title. Note that the broadcast represents exactly one YouTube video. You can
   * set this field by modifying the broadcast resource or by setting the title field of the
   * corresponding video resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The date and time that the broadcast actually ended. This information is only available once
   * the broadcast's state is complete. The value is specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ)
   * format.
   * The value returned may be {@code null}.
   */
  public DateTime getActualEndTime() {
    return actualEndTime;
  }

  /**
   * The date and time that the broadcast actually ended. This information is only available once
   * the broadcast's state is complete. The value is specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ)
   * format.
   * The value set may be {@code null}.
   */
  public LiveBroadcastSnippet setActualEndTime(DateTime actualEndTime) {
    this.actualEndTime = actualEndTime;
    return this;
  }

  /**
   * The date and time that the broadcast actually started. This information is only available once
   * the broadcast's state is live. The value is specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ)
   * format.
   * The value returned may be {@code null}.
   */
  public DateTime getActualStartTime() {
    return actualStartTime;
  }

  /**
   * The date and time that the broadcast actually started. This information is only available once
   * the broadcast's state is live. The value is specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ)
   * format.
   * The value set may be {@code null}.
   */
  public LiveBroadcastSnippet setActualStartTime(DateTime actualStartTime) {
    this.actualStartTime = actualStartTime;
    return this;
  }

  /**
   * The ID that YouTube uses to uniquely identify the channel that is publishing the broadcast.
   * The value returned may be {@code null}.
   */
  public String getChannelId() {
    return channelId;
  }

  /**
   * The ID that YouTube uses to uniquely identify the channel that is publishing the broadcast.
   * The value set may be {@code null}.
   */
  public LiveBroadcastSnippet setChannelId(String channelId) {
    this.channelId = channelId;
    return this;
  }

  /**
   * The broadcast's description. As with the title, you can set this field by modifying the
   * broadcast resource or by setting the description field of the corresponding video resource.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The broadcast's description. As with the title, you can set this field by modifying the
   * broadcast resource or by setting the description field of the corresponding video resource.
   * The value set may be {@code null}.
   */
  public LiveBroadcastSnippet setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The date and time that the broadcast was added to YouTube's live broadcast schedule. The value
   * is specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value returned may be {@code null}.
   */
  public DateTime getPublishedAt() {
    return publishedAt;
  }

  /**
   * The date and time that the broadcast was added to YouTube's live broadcast schedule. The value
   * is specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value set may be {@code null}.
   */
  public LiveBroadcastSnippet setPublishedAt(DateTime publishedAt) {
    this.publishedAt = publishedAt;
    return this;
  }

  /**
   * The date and time that the broadcast is scheduled to end. The value is specified in ISO 8601
   * (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value returned may be {@code null}.
   */
  public DateTime getScheduledEndTime() {
    return scheduledEndTime;
  }

  /**
   * The date and time that the broadcast is scheduled to end. The value is specified in ISO 8601
   * (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value set may be {@code null}.
   */
  public LiveBroadcastSnippet setScheduledEndTime(DateTime scheduledEndTime) {
    this.scheduledEndTime = scheduledEndTime;
    return this;
  }

  /**
   * The date and time that the broadcast is scheduled to start. The value is specified in ISO 8601
   * (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value returned may be {@code null}.
   */
  public DateTime getScheduledStartTime() {
    return scheduledStartTime;
  }

  /**
   * The date and time that the broadcast is scheduled to start. The value is specified in ISO 8601
   * (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value set may be {@code null}.
   */
  public LiveBroadcastSnippet setScheduledStartTime(DateTime scheduledStartTime) {
    this.scheduledStartTime = scheduledStartTime;
    return this;
  }

  /**
   * A map of thumbnail images associated with the broadcast. For each nested object in this object,
   * the key is the name of the thumbnail image, and the value is an object that contains other
   * information about the thumbnail.
   * The value returned may be {@code null}.
   */
  public ThumbnailDetails getThumbnails() {
    return thumbnails;
  }

  /**
   * A map of thumbnail images associated with the broadcast. For each nested object in this object,
   * the key is the name of the thumbnail image, and the value is an object that contains other
   * information about the thumbnail.
   * The value set may be {@code null}.
   */
  public LiveBroadcastSnippet setThumbnails(ThumbnailDetails thumbnails) {
    this.thumbnails = thumbnails;
    return this;
  }

  /**
   * The broadcast's title. Note that the broadcast represents exactly one YouTube video. You can
   * set this field by modifying the broadcast resource or by setting the title field of the
   * corresponding video resource.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The broadcast's title. Note that the broadcast represents exactly one YouTube video. You can
   * set this field by modifying the broadcast resource or by setting the title field of the
   * corresponding video resource.
   * The value set may be {@code null}.
   */
  public LiveBroadcastSnippet setTitle(String title) {
    this.title = title;
    return this;
  }

}
