/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * A playlist resource represents a YouTube playlist. A playlist is a collection of videos that can
 * be viewed sequentially and shared with other users. A playlist can contain up to 200 videos, and
 * YouTube does not limit the number of playlists that each user creates. By default, playlists are
 * publicly visible to other users, but playlists can be public or private.
 *
 * YouTube also uses playlists to identify special collections of videos for a channel, such as:   -
 * uploaded videos  - favorite videos  - positively rated (liked) videos  - watch history  - watch
 * later  To be more specific, these lists are associated with a channel, which is a collection of a
 * person, group, or company's videos, playlists, and other YouTube information. You can retrieve
 * the playlist IDs for each of these lists from the  channel resource for a given channel.
 *
 * You can then use the   playlistItems.list method to retrieve any of those lists. You can also add
 * or remove items from those lists by calling the   playlistItems.insert and   playlistItems.delete
 * methods.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Playlist extends GenericJson {

  /**
   * The contentDetails object contains information like video count.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PlaylistContentDetails contentDetails;

  /**
   * Etag of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The ID that YouTube uses to uniquely identify the playlist.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind, fixed to "youtube#playlist".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The player object contains information that you would use to play the playlist in an embedded
   * player.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PlaylistPlayer player;

  /**
   * The snippet object contains basic details about the playlist, such as its title and
   * description.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PlaylistSnippet snippet;

  /**
   * The status object contains status information for the playlist.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PlaylistStatus status;

  /**
   * The contentDetails object contains information like video count.
   * The value returned may be {@code null}.
   */
  public PlaylistContentDetails getContentDetails() {
    return contentDetails;
  }

  /**
   * The contentDetails object contains information like video count.
   * The value set may be {@code null}.
   */
  public Playlist setContentDetails(PlaylistContentDetails contentDetails) {
    this.contentDetails = contentDetails;
    return this;
  }

  /**
   * Etag of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * Etag of this resource.
   * The value set may be {@code null}.
   */
  public Playlist setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The ID that YouTube uses to uniquely identify the playlist.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID that YouTube uses to uniquely identify the playlist.
   * The value set may be {@code null}.
   */
  public Playlist setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind, fixed to "youtube#playlist".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "youtube#playlist".
   * The value set may be {@code null}.
   */
  public Playlist setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The player object contains information that you would use to play the playlist in an embedded
   * player.
   * The value returned may be {@code null}.
   */
  public PlaylistPlayer getPlayer() {
    return player;
  }

  /**
   * The player object contains information that you would use to play the playlist in an embedded
   * player.
   * The value set may be {@code null}.
   */
  public Playlist setPlayer(PlaylistPlayer player) {
    this.player = player;
    return this;
  }

  /**
   * The snippet object contains basic details about the playlist, such as its title and
   * description.
   * The value returned may be {@code null}.
   */
  public PlaylistSnippet getSnippet() {
    return snippet;
  }

  /**
   * The snippet object contains basic details about the playlist, such as its title and
   * description.
   * The value set may be {@code null}.
   */
  public Playlist setSnippet(PlaylistSnippet snippet) {
    this.snippet = snippet;
    return this;
  }

  /**
   * The status object contains status information for the playlist.
   * The value returned may be {@code null}.
   */
  public PlaylistStatus getStatus() {
    return status;
  }

  /**
   * The status object contains status information for the playlist.
   * The value set may be {@code null}.
   */
  public Playlist setStatus(PlaylistStatus status) {
    this.status = status;
    return this;
  }

}
