/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Basic details about a search result, including title, description and thumbnails of the item
 * referenced by the search result.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class SearchResultSnippet extends GenericJson {

  /**
   * The value that YouTube uses to uniquely identify the channel that published the resource that
   * the search result identifies.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelId;

  /**
   * The title of the channel that published the resource that the search result identifies.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelTitle;

  /**
   * A description of the search result.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The creation date and time of the resource that the search result identifies. The value is
   * specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime publishedAt;

  /**
   * A map of thumbnail images associated with the search result. For each object in the map, the
   * key is the name of the thumbnail image, and the value is an object that contains other
   * information about the thumbnail.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ThumbnailDetails thumbnails;

  /**
   * The title of the search result.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The value that YouTube uses to uniquely identify the channel that published the resource that
   * the search result identifies.
   * The value returned may be {@code null}.
   */
  public String getChannelId() {
    return channelId;
  }

  /**
   * The value that YouTube uses to uniquely identify the channel that published the resource that
   * the search result identifies.
   * The value set may be {@code null}.
   */
  public SearchResultSnippet setChannelId(String channelId) {
    this.channelId = channelId;
    return this;
  }

  /**
   * The title of the channel that published the resource that the search result identifies.
   * The value returned may be {@code null}.
   */
  public String getChannelTitle() {
    return channelTitle;
  }

  /**
   * The title of the channel that published the resource that the search result identifies.
   * The value set may be {@code null}.
   */
  public SearchResultSnippet setChannelTitle(String channelTitle) {
    this.channelTitle = channelTitle;
    return this;
  }

  /**
   * A description of the search result.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * A description of the search result.
   * The value set may be {@code null}.
   */
  public SearchResultSnippet setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The creation date and time of the resource that the search result identifies. The value is
   * specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value returned may be {@code null}.
   */
  public DateTime getPublishedAt() {
    return publishedAt;
  }

  /**
   * The creation date and time of the resource that the search result identifies. The value is
   * specified in ISO 8601 (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value set may be {@code null}.
   */
  public SearchResultSnippet setPublishedAt(DateTime publishedAt) {
    this.publishedAt = publishedAt;
    return this;
  }

  /**
   * A map of thumbnail images associated with the search result. For each object in the map, the
   * key is the name of the thumbnail image, and the value is an object that contains other
   * information about the thumbnail.
   * The value returned may be {@code null}.
   */
  public ThumbnailDetails getThumbnails() {
    return thumbnails;
  }

  /**
   * A map of thumbnail images associated with the search result. For each object in the map, the
   * key is the name of the thumbnail image, and the value is an object that contains other
   * information about the thumbnail.
   * The value set may be {@code null}.
   */
  public SearchResultSnippet setThumbnails(ThumbnailDetails thumbnails) {
    this.thumbnails = thumbnails;
    return this;
  }

  /**
   * The title of the search result.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The title of the search result.
   * The value set may be {@code null}.
   */
  public SearchResultSnippet setTitle(String title) {
    this.title = title;
    return this;
  }

}
