/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.common.primitives.UnsignedLong;

/**
 * Information about an audio stream.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class VideoFileDetailsAudioStream extends GenericJson {

  /**
   * The audio stream's bitrate, in bits per second.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong bitrateBps;

  /**
   * The number of audio channels that the stream contains.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Long channelCount;

  /**
   * The audio codec that the stream uses.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String codec;

  /**
   * A value that uniquely identifies a video vendor. Typically, the value is a four-letter vendor
   * code.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String vendor;

  /**
   * The audio stream's bitrate, in bits per second.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getBitrateBps() {
    return bitrateBps;
  }

  /**
   * The audio stream's bitrate, in bits per second.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsAudioStream setBitrateBps(UnsignedLong bitrateBps) {
    this.bitrateBps = bitrateBps;
    return this;
  }

  /**
   * The number of audio channels that the stream contains.
   * The value returned may be {@code null}.
   */
  public Long getChannelCount() {
    return channelCount;
  }

  /**
   * The number of audio channels that the stream contains.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsAudioStream setChannelCount(Long channelCount) {
    this.channelCount = channelCount;
    return this;
  }

  /**
   * The audio codec that the stream uses.
   * The value returned may be {@code null}.
   */
  public String getCodec() {
    return codec;
  }

  /**
   * The audio codec that the stream uses.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsAudioStream setCodec(String codec) {
    this.codec = codec;
    return this;
  }

  /**
   * A value that uniquely identifies a video vendor. Typically, the value is a four-letter vendor
   * code.
   * The value returned may be {@code null}.
   */
  public String getVendor() {
    return vendor;
  }

  /**
   * A value that uniquely identifies a video vendor. Typically, the value is a four-letter vendor
   * code.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsAudioStream setVendor(String vendor) {
    this.vendor = vendor;
    return this;
  }

}
